EXPORTS
	?findDllMethod@@YAP6APAXXZPBD@Z @ 1 NONAME ; void * (*)(void) findDllMethod(char const *)
	?asyncAccept@RFCOMMServerConnection@bluetooth@java@@QAEHPAVBluetoothPushEventListener@23@PAVBtUrlParams@23@@Z @ 2 NONAME ; int java::bluetooth::RFCOMMServerConnection::asyncAccept(class java::bluetooth::BluetoothPushEventListener *, class java::bluetooth::BtUrlParams *)
	?setCreatedByPush@RFCOMMPushServerConnection@bluetooth@java@@QAEXXZ @ 3 NONAME ; void java::bluetooth::RFCOMMPushServerConnection::setCreatedByPush(void)
	?GetRfListeningChannel@RFCOMMServerConnection@bluetooth@java@@QAEHXZ @ 4 NONAME ; int java::bluetooth::RFCOMMServerConnection::GetRfListeningChannel(void)
	?isCreatedByPush@RFCOMMPushServerConnection@bluetooth@java@@QAE_NXZ @ 5 NONAME ; bool java::bluetooth::RFCOMMPushServerConnection::isCreatedByPush(void)
	?getServiceRecordHandle@RFCOMMServerConnection@bluetooth@java@@QAEPAVServiceRecord@23@XZ @ 6 NONAME ; class java::bluetooth::ServiceRecord * java::bluetooth::RFCOMMServerConnection::getServiceRecordHandle(void)
	?isListening@RFCOMMPushServerConnection@bluetooth@java@@QAE_NXZ @ 7 NONAME ; bool java::bluetooth::RFCOMMPushServerConnection::isListening(void)
	?Accept@RFCOMMServerConnection@bluetooth@java@@QAEJXZ @ 8 NONAME ; long java::bluetooth::RFCOMMServerConnection::Accept(void)
	?initializeServiceRecord@RFCOMMServerConnection@bluetooth@java@@QAEHHAAVTUUID@@AAVTDesC8@@_N@Z @ 9 NONAME ; int java::bluetooth::RFCOMMServerConnection::initializeServiceRecord(int, class TUUID &, class TDesC8 &, bool)
	??0RFCOMMServerConnection@bluetooth@java@@QAE@PAVBluetoothFunctionServer@12@@Z @ 10 NONAME ; java::bluetooth::RFCOMMServerConnection::RFCOMMServerConnection(class java::bluetooth::BluetoothFunctionServer *)
	?open@RFCOMMPushServerConnection@bluetooth@java@@UAEXPAVConnectionListener@push@3@@Z @ 11 NONAME ; void java::bluetooth::RFCOMMPushServerConnection::open(class java::push::ConnectionListener *)
	?createSrvConnObj@BTRFCOMMServerConnectionFactory@@UAEPAVServerConnection@push@java@@ABV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@0@Z @ 12 NONAME ; class java::push::ServerConnection * BTRFCOMMServerConnectionFactory::createSrvConnObj(class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > const &, class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > const &)
	?restorePersistentRecord@RFCOMMServerConnection@bluetooth@java@@QAEHXZ @ 13 NONAME ; int java::bluetooth::RFCOMMServerConnection::restorePersistentRecord(void)
	?getConnectedClient@RFCOMMPushServerConnection@bluetooth@java@@QAEPAVBluetoothClientConnection@23@XZ @ 14 NONAME ; class java::bluetooth::BluetoothClientConnection * java::bluetooth::RFCOMMPushServerConnection::getConnectedClient(void)
	??0RFCOMMPushServerConnection@bluetooth@java@@QAE@V?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@0PAVServerConnectionFactoryBase@push@2@@Z @ 15 NONAME ; java::bluetooth::RFCOMMPushServerConnection::RFCOMMPushServerConnection(class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> >, class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> >, class java::push::ServerConnectionFactoryBase *)
	??1RFCOMMServerConnection@bluetooth@java@@QAE@XZ @ 16 NONAME ; java::bluetooth::RFCOMMServerConnection::~RFCOMMServerConnection(void)
	?isActive@RFCOMMPushServerConnection@bluetooth@java@@QAE_NXZ @ 17 NONAME ; bool java::bluetooth::RFCOMMPushServerConnection::isActive(void)
	?setFilter@RFCOMMPushServerConnection@bluetooth@java@@UAEXABV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@@Z @ 18 NONAME ; void java::bluetooth::RFCOMMPushServerConnection::setFilter(class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > const &)
	?getUri@RFCOMMPushServerConnection@bluetooth@java@@UBE?AV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@XZ @ 19 NONAME ; class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > java::bluetooth::RFCOMMPushServerConnection::getUri(void) const
	?isMultipleSrvConnAllowed@BTRFCOMMServerConnectionFactory@@UAE_NXZ @ 20 NONAME ; bool BTRFCOMMServerConnectionFactory::isMultipleSrvConnAllowed(void)
	?getServerObject@RFCOMMPushServerConnection@bluetooth@java@@QAEPAVRFCOMMServerConnection@23@XZ @ 21 NONAME ; class java::bluetooth::RFCOMMServerConnection * java::bluetooth::RFCOMMPushServerConnection::getServerObject(void)
	??1BTRFCOMMServerConnectionFactory@@UAE@XZ @ 22 NONAME ; BTRFCOMMServerConnectionFactory::~BTRFCOMMServerConnectionFactory(void)
	??0BTRFCOMMServerConnectionFactory@@QAE@XZ @ 23 NONAME ; BTRFCOMMServerConnectionFactory::BTRFCOMMServerConnectionFactory(void)
	?create@BTRFCOMMServerConnectionFactory@@UAEPAVServerConnection@push@java@@ABV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@@Z @ 24 NONAME ; class java::push::ServerConnection * BTRFCOMMServerConnectionFactory::create(class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > const &)
	?getFilter@RFCOMMPushServerConnection@bluetooth@java@@UBE?AV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@XZ @ 25 NONAME ; class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > java::bluetooth::RFCOMMPushServerConnection::getFilter(void) const
	?unsetAcceptMonitor@RFCOMMPushServerConnection@bluetooth@java@@QAEXXZ @ 26 NONAME ; void java::bluetooth::RFCOMMPushServerConnection::unsetAcceptMonitor(void)
	?ServerOpen@RFCOMMServerConnection@bluetooth@java@@QAEHHHH@Z @ 27 NONAME ; int java::bluetooth::RFCOMMServerConnection::ServerOpen(int, int, int)
	?setAcceptMonitor@RFCOMMPushServerConnection@bluetooth@java@@QAEXPAVMonitor@util@3@@Z @ 28 NONAME ; void java::bluetooth::RFCOMMPushServerConnection::setAcceptMonitor(class java::util::Monitor *)
	?close@RFCOMMPushServerConnection@bluetooth@java@@UAEXXZ @ 29 NONAME ; void java::bluetooth::RFCOMMPushServerConnection::close(void)
	?initializeServiceRecord@RFCOMMServerConnection@bluetooth@java@@QAEHHV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@0_N@Z @ 30 NONAME ; int java::bluetooth::RFCOMMServerConnection::initializeServiceRecord(int, class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> >, class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> >, bool)
	?isGOEPConnection@RFCOMMPushServerConnection@bluetooth@java@@QAE_NXZ @ 31 NONAME ; bool java::bluetooth::RFCOMMPushServerConnection::isGOEPConnection(void)
	?unsetClearServiceClassBitsFlag@RFCOMMPushServerConnection@bluetooth@java@@QAEXXZ @ 32 NONAME ; void java::bluetooth::RFCOMMPushServerConnection::unsetClearServiceClassBitsFlag(void)
	??1RFCOMMPushServerConnection@bluetooth@java@@UAE@XZ @ 33 NONAME ; java::bluetooth::RFCOMMPushServerConnection::~RFCOMMPushServerConnection(void)
	?isConnectionAccepted@RFCOMMPushServerConnection@bluetooth@java@@QAE_NXZ @ 34 NONAME ; bool java::bluetooth::RFCOMMPushServerConnection::isConnectionAccepted(void)
	?deleteServer@RFCOMMPushServerConnection@bluetooth@java@@QAEXXZ @ 35 NONAME ; void java::bluetooth::RFCOMMPushServerConnection::deleteServer(void)
	?getFactory@BTRFCOMMServerConnectionFactory@@SAAAV1@XZ @ 36 NONAME ; class BTRFCOMMServerConnectionFactory & BTRFCOMMServerConnectionFactory::getFactory(void)
	?openServer@RFCOMMServerConnection@bluetooth@java@@QAEH_N00@Z @ 37 NONAME ; int java::bluetooth::RFCOMMServerConnection::openServer(bool, bool, bool)

